#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.3.0.0-GoqUOdo7si6HLIXCUdu7lr
key:                  hls-call-hierarchy-plugin-2.3.0.0-GoqUOdo7si6HLIXCUdu7lr
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  8896240ca17c0c9bc6ed9eeb1cea02a9
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.3.0.0-GoqUOdo7si6HLIXCUdu7lr
depends:
    aeson-2.2.2.0-vFmFQLvGml64UTioNorrR base-4.18.2.1 containers-0.6.7
    extra-1.7.16-2Ws4ESP8WrPAiAEeWb6jqc
    ghcide-2.3.0.0-CoWdGXpgo9v7X1K9P59KNN
    hiedb-0.4.3.0-HFWkpvHe0kub0DZpGR82r
    hls-plugin-api-2.3.0.0-InTWXP6EhU52WB6ocwpWzm
    lens-5.3.4-IWoRR3qkHJ5zZoQTNAEtG lsp-2.2.0.0-F8G4UrPWcFQA5Bitqmz4F6
    sqlite-simple-0.4.19.0-KN9arrmybRQ4egGhKfLAaG text-2.0.2
    unordered-containers-0.2.20.1-A7v2mkdOMedFLrtoUSJIsH

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

